#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['ptyprocess']

package_data = \
{'': ['*']}

setup(name='ptyprocess',
      version='0.7.0',
      description='Run a subprocess in a pseudo terminal',
      author='Thomas Kluyver',
      author_email='thomas@kluyver.me.uk',
      url='https://github.com/pexpect/ptyprocess',
      packages=packages,
      package_data=package_data,
     )
